import { Component ,ViewChild,Inject} from '@angular/core';
import * as wjCore from 'wijmo/wijmo';
import * as wjInput from 'wijmo/wijmo.input';
import * as wjGrid from 'wijmo/wijmo.grid';
import * as wjFlexSheet from 'wijmo/wijmo.grid.sheet';
import { Hero } from './hero';
import { HeroService } from './hero.service';
import { DataSvc } from '../services/DataSvc';
@Component({
  
  selector: 'app-root',

  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent {
    
    @ViewChild('grid') grid: wjGrid.FlexGrid;
    @ViewChild('sheet') sheet: wjFlexSheet.FlexSheet;
    public title = "FlexGrid and FlexSheet";
    public gridData: wjCore.CollectionView=new wjCore.CollectionView();
    public sheetData: wjCore.CollectionView=new wjCore.CollectionView();
    private _dataSvc: HeroService;
    constructor( @Inject(HeroService) _dataSvc: HeroService, @Inject(DataSvc) _dataSvc1:DataSvc) {
        this._dataSvc = _dataSvc;
        this._dataSvc.getHeroes().then(heroes => {           
            this.gridData = new wjCore.CollectionView(heroes);
            this.gridData.trackChanges = true;
        });
        this._dataSvc.getHeroes().then(heroes => {          
            this.sheetData = new wjCore.CollectionView(heroes);
            this.sheetData.trackChanges = true;
        });
        
        
    }
    updateFlexGrid() {
            for (let i = 0; i < this.gridData.itemsEdited.length; i++) {
                if (this.gridData.itemsEdited[i].id !== undefined) {
                    this._dataSvc.update(this.gridData.itemsEdited[i]).then(() => { console.log('updated'); });
                }
            }
                  
            for (let i = 0; i < this.gridData.itemsAdded.length; i++) {
                if (this.gridData.itemsAdded[i].name !== '') {
                    this._dataSvc.create(this.gridData.itemsAdded[i].name).then(hero => {
                        console.log('Items Added', hero);
                    });
                }
            }
            for (let i = 0; i < this.gridData.itemsRemoved.length; i++) {
                if (this.gridData.itemsRemoved.length > 0) {
                    this._dataSvc.delete(this.gridData.itemsRemoved[i].id).then(() => {                            
                        console.log('Deleted deleted record ');
                    });
                }
            }
            this.gridData.itemsAdded.clear();
            this.gridData.itemsEdited.clear();
            this.gridData.itemsRemoved.clear();
            this._dataSvc.getHeroes().then(heroes => this.gridData.sourceCollection = heroes);
         //// since We are using same database for showing data, hence we need to update sheet for avoiding any concurrency 
            this._dataSvc.getHeroes().then(heroes => this.sheetData.sourceCollection = heroes);
            
        
    }
    updateFlexSheet() {
        for (let i = 0; i < this.gridData.itemsEdited.length; i++) {
            if (this.gridData.itemsEdited[i].id !== undefined) {
                this._dataSvc.update(this.gridData.itemsEdited[i]).then(() => { console.log('updated'); });
            }
        }

        for (let i = 0; i < this.gridData.itemsAdded.length; i++) {
            if (this.gridData.itemsAdded[i].name !== '') {
                this._dataSvc.create(this.gridData.itemsAdded[i].name).then(hero => {
                    console.log('Items Added', hero);
                });
            }
        }
        for (let i = 0; i < this.gridData.itemsRemoved.length; i++) {
            if (this.gridData.itemsRemoved.length > 0) {
                this._dataSvc.delete(this.gridData.itemsRemoved[i].id).then(() => {
                    console.log('Deleted deleted record ');
                });
            }
        }
        this.gridData.itemsAdded.clear();
        this.gridData.itemsEdited.clear();
        this.gridData.itemsRemoved.clear();
        this._dataSvc.getHeroes().then(heroes => this.sheetData.sourceCollection = heroes);
        
        //// since We are using same database for showing data, hence we need to update grid for avoiding any concurrency 
        this._dataSvc.getHeroes().then(heroes => this.gridData.sourceCollection = heroes);
    }
}


/*
Copyright 2017 Google Inc. All Rights Reserved.
Use of this source code is governed by an MIT-style license that
can be found in the LICENSE file at http://angular.io/license
*/